Gate

Trait Gate 

pub trait Gate<F: Field>: Downcast + DynClone {
    // Required method
    fn name(&self) -> &'static str;

    // Provided methods
    fn q_lc(&self) -> [F; 4] { ... }
    fn q_hash(&self) -> [F; 4] { ... }
    fn q_mul(&self) -> [F; 2] { ... }
    fn q_ecc(&self) -> F { ... }
    fn q_c(&self) -> F { ... }
    fn q_o(&self) -> F { ... }
    fn q_lookup(&self) -> F { ... }
    fn q_dom_sep(&self) -> F { ... }
    fn table_key(&self) -> F { ... }
    fn table_dom_sep(&self) -> F { ... }
}
Describes a gate with getter for all selectors configuration

Required Methods

fn name(&self) -> &'static str

Get the name of a gate.

Provided Methods

fn q_lc(&self) -> [F; 4]

Selectors for linear combination.

fn q_hash(&self) -> [F; 4]

Selectors for Rescue hashes.

fn q_mul(&self) -> [F; 2]

Selectors for multiplication.

fn q_ecc(&self) -> F

The selector for elliptic curve operation.

fn q_c(&self) -> F

Constant selector.

fn q_o(&self) -> F

Output wire selector.

fn q_lookup(&self) -> F

UltraPlonk lookup selector.

fn q_dom_sep(&self) -> F

UltraPlonk lookup domain separation selector.

fn table_key(&self) -> F

UltraPlonk table keys.

fn table_dom_sep(&self) -> F

UltraPlonk table domain separation ids

Implementations

Source

impl<F> dyn Gate<F>
where F: Any + 'static + Field,

pub fn is<__T: Gate<F>>(&self) -> bool

Returns true if the trait object wraps an object of type __T.

pub fn downcast<__T: Gate<F>>(self: Box<Self>) -> Result<Box<__T>, Box<Self>>

Returns a boxed object from a boxed trait object if the underlying object is of type __T. Returns the original boxed trait if it isn’t.

pub fn downcast_rc<__T: Gate<F>>(self: Rc<Self>) -> Result<Rc<__T>, Rc<Self>>

Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of type __T. Returns the original Rc-ed trait if it isn’t.

pub fn downcast_ref<__T: Gate<F>>(&self) -> Option<&__T>

Returns a reference to the object within the trait object if it is of type __T, or None if it isn’t.

pub fn downcast_mut<__T: Gate<F>>(&mut self) -> Option<&mut __T>

Returns a mutable reference to the object within the trait object if it is of type __T, or None if it isn’t.